@@ -7,7 +7,7 @@
 #  \____\___/|_| |_| |_|\___|\__(_)_| |_| |_|_|
 #
 #  Sign up for free at http://www.comet.ml
-#  Copyright (C) 2015-2020 Comet ML INC
+#  Copyright (C) 2015-2021 Comet ML INC
 #  This file can not be copied and/or distributed without the express
 #  permission of Comet ML Inc.
 # *******************************************************
@@ -149,7 +149,7 @@ def expand_log_file_path(log_file_path):
 
 def setup(config):
     root = logging.getLogger("comet_ml")
-    root.setLevel(logging.DEBUG)
+    logger_level = logging.CRITICAL
 
     # Don't send comet-ml to the application logger
     root.propagate = False
@@ -167,12 +167,16 @@ def setup(config):
         "WARN",
         "WARNING",
     ]:
-        console.setLevel(logging_console.upper())
-        console.setFormatter(logging.Formatter(MSG_FORMAT))
+        logging_console_level = logging._checkLevel(logging_console.upper())
+        console_formatter = logging.Formatter(MSG_FORMAT)
     else:
-        console.setLevel(logging.INFO)
-        console.setFormatter(TracebackLessFormatter(MSG_FORMAT))
+        logging_console_level = logging.INFO
+        console_formatter = TracebackLessFormatter(MSG_FORMAT)
+
+    console.setLevel(logging_console_level)
+    console.setFormatter(console_formatter)
     root.addHandler(console)
+    logger_level = min(logger_level, logging_console_level)
 
     # The std* logger might conflicts with the logging if a log record is
     # emitted for each WS message as it would results in an infinite loop. To
@@ -208,20 +212,25 @@ def setup(config):
             return
 
         if log_file_level is not None:
-            log_file_level = log_file_level.upper()
-            file_handler.setLevel(log_file_level)
+            log_file_level = logging._checkLevel(log_file_level.upper())
         else:
-            file_handler.setLevel(logging.DEBUG)
+            log_file_level = logging.DEBUG
+
+        file_handler.setLevel(log_file_level)
+        logger_level = min(logger_level, log_file_level)
 
         file_handler.setFormatter(logging.Formatter(FILE_MSG_FORMAT))
         root.addHandler(file_handler)
 
+    root.setLevel(logger_level)
+
 
 def setup_http_handler(url, api_key, experiment_key):
     root = logging.getLogger("comet_ml")
 
     http_handler = HTTPHandler(url, api_key, experiment_key)
-    http_handler.setLevel(logging.INFO)
+    http_handler_level = logging.INFO
+    http_handler.setLevel(http_handler_level)
 
     # Remove any other previous HTTPHandlers:
     root.handlers[:] = [
@@ -234,6 +243,9 @@ def setup_http_handler(url, api_key, experiment_key):
     # have its logs forwarded to the backend.
     root.addHandler(http_handler)
 
+    # Ensure the logger level is low enough
+    root.setLevel(min(root.level, http_handler_level))
+
     return http_handler
 
 
