@@ -7,7 +7,7 @@
 #  \____\___/|_| |_| |_|\___|\__(_)_| |_| |_|_|
 #
 #  Sign up for free at http://www.comet.ml
-#  Copyright (C) 2015-2020 Comet ML INC
+#  Copyright (C) 2015-2021 Comet ML INC
 #  This file can not be copied and/or distributed without the express
 #  permission of Comet ML Inc.
 # *******************************************************
@@ -18,7 +18,7 @@ This module contains useful types and mirror the typing module
 
 """
 from typing import *  # noqa
-from typing import IO  # noqa
+from typing import IO, Union
 
 
 class ValidFilePath(str):
@@ -37,3 +37,6 @@ class TemporaryFilePath(ValidFilePath):
 
 UserText = Union[bytes, Text]  # noqa
 MemoryUploadable = Union[IO, UserText]  # noqa
+# With typing_extensions, we could use Literal["all"]
+TensorflowInput = Union[int, str]  # noqa
+Number = Union[int, float]
