@@ -35,7 +35,11 @@ from six.moves.urllib.parse import urlencode, urlsplit, urlunsplit
 from ._reporting import ON_EXIT_DIDNT_FINISH_UPLOAD_SDK
 from ._typing import Any, Dict, List, Optional, Tuple
 from .compat_utils import json_dump
-from .config import ADDITIONAL_STREAMER_UPLOAD_TIMEOUT, DEFAULT_STREAMER_MSG_TIMEOUT
+from .config import (
+    ADDITIONAL_STREAMER_UPLOAD_TIMEOUT,
+    DEFAULT_FILE_UPLOAD_READ_TIMEOUT,
+    DEFAULT_STREAMER_MSG_TIMEOUT,
+)
 from .connection import format_messages_for_ws
 from .exceptions import CometRestApiException
 from .file_uploader import (
@@ -179,7 +183,8 @@ class Streamer(BaseStreamer):
         rest_api_client,
         pending_rpcs_callback=None,
         msg_waiting_timeout=DEFAULT_STREAMER_MSG_TIMEOUT,
-        file_upload_timeout=ADDITIONAL_STREAMER_UPLOAD_TIMEOUT,
+        file_upload_waiting_timeout=ADDITIONAL_STREAMER_UPLOAD_TIMEOUT,
+        file_upload_read_timeout=DEFAULT_FILE_UPLOAD_READ_TIMEOUT,
     ):
         super(Streamer, self).__init__(initial_offset, beat_duration / 1000.0)
         self.daemon = True
@@ -197,7 +202,8 @@ class Streamer(BaseStreamer):
 
         self.last_beat = time.time()
         self.msg_waiting_timeout = msg_waiting_timeout
-        self.file_upload_timeout = file_upload_timeout
+        self.file_upload_waiting_timeout = file_upload_waiting_timeout
+        self.file_upload_read_timeout = file_upload_read_timeout
 
         self.upload_threads = []  # type: List[threading.Thread]
 
@@ -290,6 +296,7 @@ class Streamer(BaseStreamer):
             additional_params=message.additional_params,
             metadata=message.metadata,
             clean=message.clean,
+            timeout=self.file_upload_read_timeout,
         )
         self.upload_threads.append(upload_thread)
         LOGGER.debug("Processing uploading message done")
@@ -308,6 +315,7 @@ class Streamer(BaseStreamer):
             api_key=self.api_key,
             additional_params=message.additional_params,
             metadata=message.metadata,
+            timeout=self.file_upload_read_timeout,
         )
         self.upload_threads.append(upload_thread)
         LOGGER.debug("Processing uploading message done")
@@ -326,6 +334,7 @@ class Streamer(BaseStreamer):
             api_key=self.api_key,
             additional_params=message.additional_params,
             metadata=message.metadata,
+            timeout=self.file_upload_read_timeout,
         )
         self.upload_threads.append(upload_thread)
         LOGGER.debug("Processing uploading message done")
@@ -515,11 +524,11 @@ class Streamer(BaseStreamer):
             LOGGER.info(msg)
             LOGGER.info(
                 "The Python SDK has %d seconds to finish before aborting...",
-                self.file_upload_timeout,
+                self.file_upload_waiting_timeout,
             )
             wait_for_empty(
                 self._is_file_upload_done,
-                self.file_upload_timeout,
+                self.file_upload_waiting_timeout,
                 progress_callback=self._show_remaining_file_uploads,
                 sleep_time=5,
             )
@@ -854,8 +863,18 @@ def parse_cmd_args(argv_vals):
 
     results = {}
 
-    current_key = None
+    split_argv_vals = []
     for word in argv_vals:
+        if word == "--":
+            continue  # skip it
+        elif "=" in word:
+            word_value = word.split("=", 1)
+            split_argv_vals.extend(word_value)
+        else:
+            split_argv_vals.append(word)
+
+    current_key = None
+    for word in split_argv_vals:
         word = word.strip()
         prefix = 0
 
