@@ -65,6 +65,8 @@ DEFAULT_STREAMER_MSG_TIMEOUT = 60 * 60  # 1 Hour
 
 ADDITIONAL_STREAMER_UPLOAD_TIMEOUT = 3 * 60 * 60  # 3 hours
 
+DEFAULT_FILE_UPLOAD_READ_TIMEOUT = 900
+
 
 def get_global_experiment():
     global experiment
@@ -616,7 +618,10 @@ CONFIG_MAP = {
     },
     "comet.timeout.http": {"type": int, "default": 10},
     "comet.timeout.api": {"type": int, "default": 10},
-    "comet.timeout.file_upload": {"type": int, "default": 900},
+    "comet.timeout.file_upload": {
+        "type": int,
+        "default": DEFAULT_FILE_UPLOAD_READ_TIMEOUT,
+    },
     "comet.timeout.file_download": {"type": int, "default": 600},
     "comet.timeout.predictor": {"type": int, "default": 60},
     # HTTP Allow header
