@@ -39,7 +39,7 @@ from ._typing import (
     UserText,
     ValidFilePath,
 )
-from .config import Config, get_config
+from .config import get_config
 from .connection import Reporting, get_http_session
 from .exceptions import FileIsTooBig
 from .logging_messages import (
@@ -80,19 +80,23 @@ def compress_git_patch(git_patch):
     return archive, zip_path
 
 
-def _send_file(url, data, params, experiment_id, config, headers):
-    # type: (str, Any, Dict[str, str], str, Config, Dict[str, Any]) -> Response
-    LOGGER.debug("Uploading files %r to %s with params %s", data, url, params)
+def _get_clientlib_params(experiment_id, project_id, api_key):
+    # type: (str, str, str) -> Dict[str, str]
+    return {"experimentId": experiment_id, "projectId": project_id, "apiKey": api_key}
 
-    headers.update({"X-COMET-DEBUG-EXPERIMENT-KEY": experiment_id})
+
+def _get_clientlib_headers(experiment_id):
+    # type: (str) -> Dict[str, str]
+    return {"X-COMET-DEBUG-EXPERIMENT-KEY": experiment_id}
+
+
+def _send_file(url, data, params, headers, timeout):
+    # type: (str, Any, Dict[str, str], Dict[str, Any], int) -> Response
+    LOGGER.debug("Uploading files %r to %s with params %s", data, url, params)
 
     with get_http_session() as session:
         r = session.post(
-            url,
-            params=params,
-            data=data,
-            timeout=config["comet.timeout.file_upload"],
-            headers=headers,
+            url, params=params, data=data, timeout=timeout, headers=headers,
         )  # type: Response
 
     LOGGER.debug("Uploading file to %s done", url)
@@ -111,16 +115,12 @@ def send_file(
     experiment_id,
     project_id,
     file_path,
-    config,
-    additional_params=None,
+    params,
+    headers,
+    timeout,
     metadata=None,
 ):
-    # type: (str, str, str, str, str, Config, Optional[Dict[str, str]], Optional[Dict[Any, Any]]) -> Response
-    params = {"experimentId": experiment_id, "projectId": project_id, "apiKey": api_key}
-
-    if additional_params is not None:
-        params.update(additional_params)
-
+    # type: (str, str, str, str, str, Dict[str, str], Dict[str, str], int, Optional[Dict[Any, Any]]) -> Response
     with open(file_path, "rb") as _file:
         fields = {"file": ("file", _file)}  # type: Dict[str, Any]
 
@@ -131,13 +131,10 @@ def send_file(
 
         data = MultipartEncoder(fields=fields)
 
+        headers.update({"Content-Type": data.content_type})
+
         return _send_file(
-            post_endpoint,
-            params=params,
-            data=data,
-            experiment_id=experiment_id,
-            config=config,
-            headers={"Content-Type": data.content_type},
+            post_endpoint, params=params, data=data, timeout=timeout, headers=headers,
         )
 
 
@@ -147,16 +144,12 @@ def send_file_like(
     experiment_id,
     project_id,
     file_like,
-    config,
-    additional_params=None,
+    params,
+    headers,
+    timeout,
     metadata=None,
 ):
-    # type: (str, str, str, str, Any, Config, Optional[Dict[str, str]], Optional[Dict[Any, Any]]) -> Response
-    params = {"experimentId": experiment_id, "projectId": project_id, "apiKey": api_key}
-
-    if additional_params is not None:
-        params.update(additional_params)
-
+    # type: (str, str, str, str, Any, Dict[str, str], Dict[str, str], int, Optional[Dict[Any, Any]]) -> Response
     fields = {"file": ("file", file_like)}  # type: Dict[str, Any]
 
     if metadata is not None:
@@ -166,13 +159,10 @@ def send_file_like(
 
     data = MultipartEncoder(fields=fields)
 
+    headers.update({"Content-Type": data.content_type})
+
     return _send_file(
-        post_endpoint,
-        params=params,
-        data=data,
-        experiment_id=experiment_id,
-        config=config,
-        headers={"Content-Type": data.content_type},
+        post_endpoint, params=params, data=data, timeout=timeout, headers=headers,
     )
 
 
@@ -182,15 +172,12 @@ def send_remote_asset(
     experiment_id,
     project_id,
     remote_uri,
-    config,
-    additional_params=None,
+    params,
+    headers,
+    timeout,
     metadata=None,
 ):
-    # type: (str, str, str, str, str, Config, Optional[Dict[str, str]], Optional[Dict[Any, Any]]) -> Response
-    params = {"experimentId": experiment_id, "projectId": project_id, "apiKey": api_key}
-
-    if additional_params is not None:
-        params.update(additional_params)
+    # type: (str, str, str, str, str, Dict[str, str], Dict[str, str], int, Optional[Dict[Any, Any]]) -> Response
 
     fields = {"link": ("link", remote_uri)}  # type: Dict[str, Any]
 
@@ -201,13 +188,10 @@ def send_remote_asset(
 
     data = MultipartEncoder(fields=fields)
 
+    headers.update({"Content-Type": data.content_type})
+
     return _send_file(
-        post_endpoint,
-        params=params,
-        data=data,
-        experiment_id=experiment_id,
-        config=config,
-        headers={"Content-Type": data.content_type},
+        post_endpoint, params=params, data=data, timeout=timeout, headers=headers,
     )
 
 
@@ -217,11 +201,17 @@ def upload_file(
     file_path,
     upload_endpoint,
     api_key,
+    timeout,
     additional_params=None,
     metadata=None,
     clean=True,
 ):
-    config = get_config()
+    params = _get_clientlib_params(experiment_id, project_id, api_key)
+
+    if additional_params is not None:
+        params.update(additional_params)
+
+    headers = _get_clientlib_headers(experiment_id)
 
     try:
         response = send_file(
@@ -230,9 +220,10 @@ def upload_file(
             experiment_id,
             project_id,
             file_path,
-            additional_params=additional_params,
+            params=params,
+            headers=headers,
             metadata=metadata,
-            config=config,
+            timeout=timeout,
         )
 
         if clean is True:
@@ -255,7 +246,7 @@ def upload_file(
             project_id=project_id,
             api_key=api_key,
             err_msg=str(e),
-            config=config,
+            config=get_config(),
         )
 
 
@@ -265,10 +256,16 @@ def upload_file_like(
     file_like,
     upload_endpoint,
     api_key,
+    timeout,
     additional_params=None,
     metadata=None,
 ):
-    config = get_config()
+    params = _get_clientlib_params(experiment_id, project_id, api_key)
+
+    if additional_params is not None:
+        params.update(additional_params)
+
+    headers = _get_clientlib_headers(experiment_id)
 
     try:
         response = send_file_like(
@@ -277,9 +274,10 @@ def upload_file_like(
             experiment_id,
             project_id,
             file_like,
-            config,
-            additional_params=additional_params,
+            params=params,
+            headers=headers,
             metadata=metadata,
+            timeout=timeout,
         )
 
         LOGGER.debug(
@@ -295,7 +293,7 @@ def upload_file_like(
             project_id=project_id,
             api_key=api_key,
             err_msg=str(e),
-            config=config,
+            config=get_config(),
         )
 
 
@@ -305,10 +303,16 @@ def upload_remote_asset(
     remote_uri,
     upload_endpoint,
     api_key,
+    timeout,
     additional_params=None,
     metadata=None,
 ):
-    config = get_config()
+    params = _get_clientlib_params(experiment_id, project_id, api_key)
+
+    if additional_params is not None:
+        params.update(additional_params)
+
+    headers = _get_clientlib_headers(experiment_id)
 
     try:
         response = send_remote_asset(
@@ -317,9 +321,10 @@ def upload_remote_asset(
             experiment_id,
             project_id,
             remote_uri,
-            config,
-            additional_params=additional_params,
+            params=params,
+            headers=headers,
             metadata=metadata,
+            timeout=timeout,
         )
 
         LOGGER.debug(
@@ -335,7 +340,7 @@ def upload_remote_asset(
             project_id=project_id,
             api_key=api_key,
             err_msg=str(e),
-            config=config,
+            config=get_config(),
         )
 
 
@@ -385,7 +390,7 @@ def is_user_text(input):
 
 
 def check_max_file_size(file_path, max_upload_size, too_big_msg):
-    # type: (str, int, str) -> int
+    # type: (str, int, str) -> None
     """Check if a file identified by its file path is bigger than the maximum
     allowed upload size. Raises FileIsTooBig if the file is greater than the
     upload limit.
