@@ -7,7 +7,7 @@
 #  \____\___/|_| |_| |_|\___|\__(_)_| |_| |_|_|
 #
 #  Sign up for free at http://www.comet.ml
-#  Copyright (C) 2015-2020 Comet ML INC
+#  Copyright (C) 2015-2021 Comet ML INC
 #  This file can not be copied and/or distributed without
 #  the express permission of Comet ML Inc.
 # *******************************************************
@@ -79,7 +79,7 @@ def add_summary_logger(experiment, original, value, *args, **kwargs):
                     "ignoring tensorflow summary log of metrics because of keras; set `comet_ml.loggers.tensorboard_logger.LOG_METRICS = True` to override",
                 )
 
-        if histograms and experiment.auto_weight_logging:
+        if histograms and experiment.auto_histogram_tensorboard_logging:
             if LOG_HISTOGRAMS:
                 for histo in histograms:
                     experiment.log_histogram_3d(convert_histograms(histo), step=step)
@@ -151,7 +151,7 @@ def summary_image_logger(experiment, original, value, *args, **kwargs):
 
 def summary_histogram_3d_logger(experiment, original, value, *args, **kwargs):
     try:
-        if experiment.auto_weight_logging:
+        if experiment.auto_histogram_tensorboard_logging:
             if LOG_HISTOGRAMS:
                 name, data, step = get_args(*args, **kwargs)
                 experiment.log_histogram_3d(data, name, step=step)
