@@ -7,11 +7,12 @@
 #  \____\___/|_| |_| |_|\___|\__(_)_| |_| |_|_|
 #
 #  Sign up for free at http://www.comet.ml
-#  Copyright (C) 2015-2020 Comet ML INC
+#  Copyright (C) 2015-2021 Comet ML INC
 #  This file can not be copied and/or distributed without the express
 #  permission of Comet ML Inc.
 # *******************************************************
 
+import copy
 import logging
 from functools import partial
 
@@ -87,7 +88,7 @@ def _comet_xgboost_callback(experiment, env):
     # Then log the parameters
     try:
         if experiment.auto_param_logging:
-            if not experiment._storage["xgboost"].get("env_parameter_set", False):
+            if not experiment._storage["xgboost"]["env_parameter_set"]:
                 for attribute_name, attribute_value in _get_env_params(env):
                     experiment._log_parameter(
                         attribute_name, attribute_value, framework="xgboost"
@@ -101,7 +102,7 @@ def _comet_xgboost_callback(experiment, env):
     # Then log the model attributes
     try:
         if experiment.auto_param_logging:
-            if not experiment._storage["xgboost"].get("env_model_parameter_set", False):
+            if not experiment._storage["xgboost"]["env_model_parameter_set"]:
 
                 booster = env.model
                 for attribute_name, attribute_value in _get_env_model_params(booster):
@@ -127,7 +128,7 @@ def _comet_xgboost_callback(experiment, env):
     # And finally the model
     try:
         if experiment.log_graph:
-            if not experiment._storage["xgboost"].get("model_graph_set", False):
+            if not experiment._storage["xgboost"]["model_graph_set"]:
                 booster = env.model
 
                 booster_graph = _get_booster_graph(booster)
@@ -153,7 +154,7 @@ def _safe_comet_xgboost_callback(experiment, env):
 def _log_xgboost_train_parameters(experiment, xgboost_params):
     # type: (BaseExperiment, Dict[str, Any]) -> None
     # Log XGBoost parameters
-    if not experiment._storage["xgboost"].get("train_parameter_set", False):
+    if not experiment._storage["xgboost"]["train_parameter_set"]:
         params = {
             key: value for key, value in xgboost_params.items() if value is not None
         }
@@ -168,13 +169,25 @@ def _xgboost_train(experiment, original, *args, **kwargs):
 
         if callbacks is None:
             callbacks = []
-            args = args[:11] + (callbacks,) + args[12:]
+        else:
+            # Copy callbacks list to avoid in-place mutation, it's gonna be the default behavior in
+            # XGBoost anyway https://github.com/dmlc/xgboost/pull/6320
+            callbacks = copy.copy(callbacks)
+
+        # Inject or replace callbacks in new args
+        args = args[:11] + (callbacks,) + args[12:]
     # Keyword args
     else:
         callbacks = kwargs.get("callbacks", None)
         if callbacks is None:
             callbacks = []
-            kwargs["callbacks"] = callbacks
+        else:
+            # Copy callbacks list to avoid in-place mutation, it's gonna be the default behavior in
+            # XGBoost anyway https://github.com/dmlc/xgboost/pull/6320
+            callbacks = copy.copy(callbacks)
+
+        # Inject or replace callbacks in new kwargs
+        kwargs["callbacks"] = callbacks
 
     callbacks.append(partial(_safe_comet_xgboost_callback, experiment))
 
