@@ -7,7 +7,7 @@
 #  \____\___/|_| |_| |_|\___|\__(_)_| |_| |_|_|
 #
 #  Sign up for free at http://www.comet.ml
-#  Copyright (C) 2015-2020 Comet ML INC
+#  Copyright (C) 2015-2021 Comet ML INC
 #  This file can not be copied and/or distributed without
 #  the express permission of Comet ML Inc.
 # *******************************************************
@@ -195,3 +195,49 @@ CONFUSION_MATRIX_EXAMPLE_NONE = "%r returned None for index %s; example not gene
 CONFUSION_MATRIX_EXAMPLE_DICT_INVALID_FORMAT = "%r returned an invalid dict for index %s, must match {'sample': ..., 'assetId': ...}"
 
 CONFUSION_MATRIX_EXAMPLE_INVALID_TYPE = "%r returned invalid type %r at index %s, must return an int, string, URL, or {'sample': string, 'assetId': string}"
+
+MISSING_PANDAS_LOG_DATAFRAME = "pandas is required to log a dataframe; ignoring"
+
+MISSING_PANDAS_PROFILING = "pandas_profiling is required to log profile; ignoring"
+
+NOT_PANDAS_DATAFRAME = "dataframe must be a pandas DataFrame; ignoring"
+
+DATAFRAME_PROFILE_ERROR = "unable to profile dataframe; ignoring"
+
+LOG_CODE_CALLER_NOT_FOUND = "unable to find caller source code; ignoring"
+
+LOG_CODE_CALLER_JUPYTER = (
+    "unable to find caller source code in a jupyter notebook; ignoring"
+)
+
+LOG_CODE_FILE_NAME_FOLDER_MUTUALLY_EXCLUSIVE = "Experiment.log_code either only one of code, file_name or folder, not several; ignoring"
+
+# LOG_CLOUD_POINTS_3D
+
+INVALID_CLOUD_POINTS_3D = "Invalid 3d points list: %r; ignoring"
+
+INVALID_SINGLE_CLOUD_POINT_3D_LENGTH = "Invalid single 3d point length: %r, it should be a list or equivalent of size 3 minimum; ignoring"
+
+INVALID_SINGLE_CLOUD_POINT_3D = (
+    "Invalid single 3d point: %r, it should be a list or equivalent; ignoring"
+)
+
+INVALID_BOUNDING_BOX_3D = (
+    "Invalid box %r, it should be a dict in the documented format; ignoring"
+)
+
+INVALID_BOUNDING_BOXES_3D = "Invalid list of boxes %r, it should be a list of dict in the documented format; ignoring it"
+
+LOG_CLOUD_POINTS_3D_NO_VALID = "No valid points or valid boxes logged; ignoring"
+
+SET_CODE_FILENAME_DEPRECATED = "Experiment.set_code(filename=...) is deprecated, use Experiment.log_code(file_name=...) instead"
+
+SET_CODE_CODE_DEPRECATED = "Experiment.set_code(code=...) is deprecated, use Experiment.log_code(code=..., code_name=...) instead"
+
+LOG_CODE_MISSING_CODE_NAME = "code_name is mandatory when passing in `code`; ignoring"
+
+LOG_PARAMS_EMPTY_MAPPING = "Empty mapping given to log_params(%r); ignoring"
+
+LOG_PARAMS_EMPTY_CONVERTED_MAPPING = (
+    "%r passed to log_params converted to an empty maping; ignoring"
+)
