@@ -7,7 +7,7 @@
 #  \____\___/|_| |_| |_|\___|\__(_)_| |_| |_|_|
 #
 #  Sign up for free at http://www.comet.ml
-#  Copyright (C) 2015-2020 Comet ML INC
+#  Copyright (C) 2015-2021 Comet ML INC
 #  This file can not be copied and/or distributed without the express
 #  permission of Comet ML Inc.
 # *******************************************************
@@ -45,22 +45,13 @@ from ._typing import (
     Tuple,
     Union,
 )
+from .compat_utils import Mapping, StringIO
 from .convert_utils import convert_tensor_to_numpy
-
-if six.PY2:
-    from collections import Mapping
-else:
-    from collections.abc import Mapping
-
+from .logging_messages import DATAFRAME_PROFILE_ERROR, MISSING_PANDAS_PROFILING
 
 LOGGER = logging.getLogger(__name__)
 LOG_ONCE_CACHE = set()  # type: Set[str]
 
-if six.PY2:
-    from StringIO import StringIO
-else:
-    StringIO = io.StringIO
-
 
 if hasattr(time, "monotonic"):
     get_time_monotonic = time.monotonic
@@ -178,13 +169,13 @@ def local_timestamp():
     return timestamp_in_milliseconds
 
 
-def wait_for_empty(check_function, timeout, verbose=False, sleep_time=1):
+def wait_for_empty(check_function, timeout, progress_callback=None, sleep_time=1):
     """ Wait up to TIMEOUT seconds for the messages queue to be empty
     """
     end_time = time.time() + timeout
     while check_function() is False and time.time() < end_time:
-        if verbose is True:
-            LOGGER.info("Still uploading")
+        if progress_callback is not None:
+            progress_callback()
         # Wait a max of sleep_time, but keep checking to see if
         # check_function is done. Allows wait_for_empty to end
         # before sleep_time has elapsed:
@@ -579,13 +570,15 @@ def write_file_like_to_tmp_file(file_like_object, tmpdir):
 
     buf = file_like_object.read(1)
 
+    tmp_file = tempfile.NamedTemporaryFile(mode="w+b", dir=tmpdir, delete=False)
+
+    encode = False
+
     # Detect binary/text
-    if isinstance(buf, six.binary_type):
-        tmp_file_mode = "w+b"
-    else:
-        tmp_file_mode = "w+"
+    if not isinstance(buf, bytes):
+        encode = True
+        buf = buf.encode("utf-8")
 
-    tmp_file = tempfile.NamedTemporaryFile(mode=tmp_file_mode, dir=tmpdir, delete=False)
     tmp_file.write(buf)
 
     # Main copy loop
@@ -595,6 +588,9 @@ def write_file_like_to_tmp_file(file_like_object, tmpdir):
         if not buf:
             break
 
+        if encode:
+            buf = buf.encode("utf-8")
+
         tmp_file.write(buf)
 
     return tmp_file.name
@@ -938,12 +934,12 @@ class Histogram(object):
         except Exception:
             pass
 
-        if len(values) == 0:
-            return
-
         # Returns numpy array, if possible:
         values = fast_flatten(values)
 
+        if len(values) == 0:
+            return
+
         if HAS_NUMPY:
             if counts is not None:
                 counts = numpy.array(counts)
@@ -1328,11 +1324,23 @@ def get_user():
         return "unknown"
 
 
-def log_asset_folder(folder, recursive=False):
-    # type: (str, bool) -> Generator[Tuple[str, str], None, None]
+def log_asset_folder(folder, recursive=False, extension_filter=None):
+    # type: (str, bool, Optional[List[str]]) -> Generator[Tuple[str, str], None, None]
+    extension_filter_set = None
+
+    if extension_filter is not None:
+        extension_filter_set = set(extension_filter)
+
     if recursive:
-        for dirpath, _, filenames in os.walk(folder):
-            for file_name in filenames:
+        for dirpath, _, file_names in os.walk(folder):
+            for file_name in file_names:
+
+                if extension_filter_set:
+                    file_extension = os.path.splitext(file_name)[1]
+
+                    if file_extension not in extension_filter_set:
+                        continue
+
                 file_path = os.path.join(dirpath, file_name)
                 yield (file_name, file_path)
     else:
@@ -1340,6 +1348,12 @@ def log_asset_folder(folder, recursive=False):
         for file_name in file_names:
             file_path = os.path.join(folder, file_name)
             if os.path.isfile(file_path):
+
+                if extension_filter_set:
+                    file_extension = os.path.splitext(file_name)[1]
+                    if file_extension not in extension_filter_set:
+                        continue
+
                 yield (file_name, file_path)
 
 
@@ -1441,6 +1455,20 @@ def shape(data):
             return []
 
 
+def tensor_length(data):
+    """
+    Get the length of a tensor/list.
+    """
+    if hasattr(data, "shape"):
+        return data.shape[0]
+    else:
+        try:
+            length = len(data)
+        except TypeError:
+            length = 0
+    return length
+
+
 def lazy_flatten(iterable):
     if hasattr(iterable, "flatten"):
         iterable = iterable.flatten()
@@ -1709,7 +1737,9 @@ def convert_object_to_dictionary(obj):
 
     dic = {}
     for attr in dir(obj):
-        if attr.startswith("__") or attr.startswith("to_"):
+        # Python 2 exposed some "internal" functions attributed as `func_X`. They were renamed in
+        # `__X__` in Python 3.
+        if attr.startswith("__") or attr.startswith("to_") or attr.startswith("func_"):
             continue
         value = getattr(obj, attr)
         if callable(value):
@@ -1719,3 +1749,72 @@ def convert_object_to_dictionary(obj):
         except Exception:
             pass
     return dic
+
+
+def check_is_pandas_dataframe(dataframe):
+    # type: (Any) -> Optional[bool]
+    """
+    Is it like a dataframe? For example, does it have
+    to_markdown(), to_html() methods?
+    """
+    try:
+        from pandas.core.dtypes.generic import ABCDataFrame, ABCSeries
+    except ImportError:
+        return None
+
+    return isinstance(dataframe, (ABCDataFrame, ABCSeries))
+
+
+def get_dataframe_profile_html(dataframe, minimal):
+    # type: (Any, Optional[bool]) -> Optional[str]
+    """
+    Log a pandas dataframe profile.
+    """
+    try:
+        import pandas_profiling
+
+    except ImportError:
+        LOGGER.warning(MISSING_PANDAS_PROFILING)
+        return None
+    except Exception:
+        LOGGER.warning(MISSING_PANDAS_PROFILING, exc_info=True)
+        return None
+
+    try:
+        if minimal:  # earlier versions of pandas_profiling did not support minimal
+            profile = pandas_profiling.ProfileReport(dataframe, minimal=minimal)
+        else:
+            profile = pandas_profiling.ProfileReport(dataframe)
+        html = profile.to_html()  # type: str
+        html = html.replace("http:", "https:")
+        return html
+    except Exception:
+        LOGGER.warning(DATAFRAME_PROFILE_ERROR, exc_info=True)
+
+        return None
+
+
+def prepare_dataframe(dataframe, asset_format, **kwargs):
+    # type: (Any, Optional[str], Optional[dict]) -> Optional[StringIO]
+    """
+    Log a pandas dataframe.
+    """
+    fp = StringIO()
+    if asset_format == "json":
+        dataframe.to_json(fp, **kwargs)
+    elif asset_format == "csv":
+        dataframe.to_csv(fp, **kwargs)
+    elif asset_format == "md":
+        dataframe.to_markdown(fp, **kwargs)
+    elif asset_format == "html":
+        dataframe.to_html(fp, **kwargs)
+    else:
+        LOGGER.warning(
+            "invalid asset_format %r; should be 'json', "
+            + "'csv', 'md', or 'html'; ignoring",
+            asset_format,
+        )
+        return None
+
+    fp.seek(0)
+    return fp
